# Radio Intelligence Apps

Stay tuned for the upcoming release of [Radio Intelligence Apps](https://www.qoherent.ai/radiointelligenceapps-suite/)
by [Qoherent](https://www.qoherent.ai/)! 📡🚀

Note: We are currently in the testing phase, and the current functionality is limited to making a cat meow. 🐱

## Getting Started
RIA Core is avaiable at [PyPI](https://pypi.org/project/ria), and can be installed with pip:
```sh
pip install ria
```

## Exploring the Command Line Functionality
```sh
meow --name "Whiskers" --age 3 --color "gray"
```

## Exploring the Import Functionality

```python
from ria.Cat import Cat

my_cat = Cat(name="Whiskers", age=3, color="gray")
print(my_cat.meow())
```
